(v0.4.0)=
### 0.4.0 {small}`23 December, 2017`

- read/write [.loom](https://loompy.org) files
- scalability beyond dataset sizes that fit into memory: see this [blog post]
- {class}`~anndata.AnnData` has a {class}`~anndata.AnnData.raw` attribute, which simplifies storing the data matrix when you consider it *raw*: see the [clustering tutorial]

[blog post]: http://falexwolf.de/blog/171223_AnnData_indexing_views_HDF5-backing/
[clustering tutorial]: https://github.com/scverse/scanpy_usage/tree/master/170505_seurat
